@@ -5,6 +5,7 @@ import json
 from inelsmqtt import InelsMqtt
 from inelsmqtt.const import (
     DEVICE_TYPE_DICT,
+    FRAGMENT_DOMAIN,
     TOPIC_FRAGMENTS,
     FRAGMENT_DEVICE_TYPE,
     FRAGMENT_SERIAL_NUMBER,
@@ -25,7 +26,6 @@ class Device(object):
         self,
         mqtt: InelsMqtt,
         state_topic: str,
-        set_topic: str,
         payload: str,
         title: str = None,
     ) -> None:
@@ -48,9 +48,15 @@ class Device(object):
         self.__unique_id = fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]
         self.__parent_id = fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]
         self.__state_topic = state_topic
-        self.__set_topic = set_topic
+        self.__set_topic = f"""
+            {fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/
+            {fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/
+            set/
+            {fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/
+            {fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"""
         self.__payload = payload
         self.__title = title if title is not None else self.__unique_id
+        self.__domain = fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]
 
     @property
     def unique_id(self) -> str:
@@ -115,7 +121,39 @@ class Device(object):
         self.__payload = payload
         return self.__mqtt.publish(self.__set_topic, self.__payload)
 
-    def info(self) -> str:
+    @property
+    def set_topic(self) -> str:
+        """Set topic
+
+        Returns:
+            str: string of the set topic
+        """
+        return self.__set_topic
+
+    @property
+    def state_topic(self) -> str:
+        """State topic
+
+        Returns:
+            str: string of the status topic
+        """
+        return self.__state_topic
+
+    @property
+    def domain(self) -> str:
+        """Domain name of the topic
+           it should represent the manufacturer
+
+        Returns:
+            str: Name of the domain
+        """
+        return self.__domain
+
+    def info(self):
+        """Device info."""
+        return DeviceInfo(self)
+
+    def info_serialized(self) -> str:
         """Device info in json format string
 
         Returns:
@@ -132,3 +170,35 @@ class Device(object):
         _LOGGER.info("Device: %s", json_serialized)
 
         return json_serialized
+
+
+class DeviceInfo(object):
+    """Device info class."""
+
+    def __init__(self, device: Device) -> None:
+        """Create object of the class
+
+        Args:
+            device (Device): device object
+        """
+        self.__device = device
+
+    @property
+    def manufacturer(self) -> str:
+        """Manufacturer property."""
+        return self.__device.domain
+
+    @property
+    def model_number(self) -> str:
+        """Modle of the device."""
+        return "TODO: model"
+
+    @property
+    def sw_version(self) -> str:
+        """Sw version of the device."""
+        return "TODO: Sw version"
+
+    @property
+    def serial_number(self) -> str:
+        """Serial number of the device."""
+        return self.__device.unique_id
